# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xb7\x02\n\x12IntradayRsiRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x16\n\x06length\x18\x04 \x01(\x05R\x06length\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"l\n\x13IntradayRsiResponse\x12U\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayRsiDataR\x04\x64\x61ta\"t\n\x0fIntradayRsiData\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x10\n\x03rsi\x18\x03 \x01(\x01R\x03rsi2\xcb\x01\n\x12IntradayRsiService\x12\xb4\x01\n\x0bIntradayRsi\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayRsiRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayRsiResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/intraday/rsiB\xa9\x02\n4com.systemathics.apis.services.intraday_analytics.v1B\x10IntradayRsiProtoP\x01\xa2\x02\x04SASI\xaa\x02/Systemathics.Apis.Services.IntradayAnalytics.V1\xca\x02/Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\xe2\x02;Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\\GPBMetadata\xea\x02\x33Systemathics::Apis::Services::IntradayAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4com.systemathics.apis.services.intraday_analytics.v1B\020IntradayRsiProtoP\001\242\002\004SASI\252\002/Systemathics.Apis.Services.IntradayAnalytics.V1\312\002/Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\342\002;Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\\GPBMetadata\352\0023Systemathics::Apis::Services::IntradayAnalytics::V1'
  _globals['_INTRADAYRSISERVICE'].methods_by_name['IntradayRsi']._options = None
  _globals['_INTRADAYRSISERVICE'].methods_by_name['IntradayRsi']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/intraday/rsi'
  _globals['_INTRADAYRSIREQUEST']._serialized_start=339
  _globals['_INTRADAYRSIREQUEST']._serialized_end=650
  _globals['_INTRADAYRSIRESPONSE']._serialized_start=652
  _globals['_INTRADAYRSIRESPONSE']._serialized_end=760
  _globals['_INTRADAYRSIDATA']._serialized_start=762
  _globals['_INTRADAYRSIDATA']._serialized_end=878
  _globals['_INTRADAYRSISERVICE']._serialized_start=881
  _globals['_INTRADAYRSISERVICE']._serialized_end=1084
# @@protoc_insertion_point(module_scope)
