# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bars.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/tick_analytics/v1/tick_bars.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xeb\x03\n\x0fTickBarsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12L\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.BarPriceR\x05\x66ield\x12\x35\n\x08sampling\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08sampling\x12\x31\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06period\x12\x31\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06offset\x12\x1e\n\nadjustment\x18\x07 \x01(\x08R\nadjustment\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x08 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\t \x03(\tR\x06reject\"\xdf\x01\n\x10TickBarsResponse\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x14\n\x05\x63lose\x18\x05 \x01(\x01R\x05\x63lose\x12\x16\n\x06volume\x18\x06 \x01(\x03R\x06volume\x12\x14\n\x05\x63ount\x18\x07 \x01(\x05R\x05\x63ount\x12\x12\n\x04vwap\x18\x08 \x01(\x01R\x04vwap*`\n\x08\x42\x61rPrice\x12\x19\n\x15\x42\x41R_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41R_PRICE_TRADE\x10\x01\x12\x11\n\rBAR_PRICE_BID\x10\x02\x12\x11\n\rBAR_PRICE_ASK\x10\x03\x32\xc0\x01\n\x0fTickBarsService\x12\xac\x01\n\x08TickBars\x12=.systemathics.apis.services.tick_analytics.v1.TickBarsRequest\x1a>.systemathics.apis.services.tick_analytics.v1.TickBarsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/tick-analytics/bars0\x01\x42\x92\x02\n0com.systemathics.apis.services.tick_analytics.v1B\rTickBarsProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_bars_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\rTickBarsProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKBARSSERVICE'].methods_by_name['TickBars']._loaded_options = None
  _globals['_TICKBARSSERVICE'].methods_by_name['TickBars']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/tick-analytics/bars'
  _globals['_BARPRICE']._serialized_start=1028
  _globals['_BARPRICE']._serialized_end=1124
  _globals['_TICKBARSREQUEST']._serialized_start=309
  _globals['_TICKBARSREQUEST']._serialized_end=800
  _globals['_TICKBARSRESPONSE']._serialized_start=803
  _globals['_TICKBARSRESPONSE']._serialized_end=1026
  _globals['_TICKBARSSERVICE']._serialized_start=1127
  _globals['_TICKBARSSERVICE']._serialized_end=1319
# @@protoc_insertion_point(module_scope)
